--[[
AnimatedIndoorParts

Script to animate some indoor parts in combination with the gear box addon by mogli or drivecontrol by upsidedown

@Author:	Ifko[nator]
@Date:		05.08.2018

@Version:	2.1

@History:	1.0 @01.02.2017 - initial release in FS 17
			--------------------------------------------------------------------------------------------------
			1.5 @11.11.2017 - added functions for: oil pressure light, air pressure light and handbrake light
							- some code improvements
			--------------------------------------------------------------------------------------------------
			2.0 @08.06.2018 - added function for direction arrows
							- added function for turn lights from trailers
							- added function for fill level hud from trailers
							- added function for fill weight hud from trailers
							- added function for manys indoor symbols
			--------------------------------------------------------------------------------------------------
			2.1 @05.08.2018 - the throttle is no longer animated when reverse driving is active
							- added support for front hydraulic, back hydraulic, trailer and trailer low buttons and cruise control wheels
]]

AnimatedIndoorParts={}function AnimatedIndoorParts.prerequisitesPresent(a)return SpecializationUtil.hasSpecialization(AnimatedVehicle,a)end;function AnimatedIndoorParts:load(b)self.handThrottle=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.handThrottle#index"))self.clutch=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.clutch#index"))self.brake=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.brake#index"))self.throttle=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.throttle#index"))self.throttleLinkage=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.throttle#indexLinkage"))self.handThrottleMaxRotY=Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.handThrottle#maxRotY"),-55)self.brakeMaxRotX=Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.brake#maxRotX"),-35)self.throttleMaxRotX=Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.throttle#maxRotX"),-14)self.buttonFrontHydraulic=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.frontHydraulic#index"))self.buttonBackHydraulic=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.backHydraulic#index"))self.buttonBackTrailerLow=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.backTrailerLow#index"))self.buttonBackTrailer=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.backTrailer#index"))self.buttonCruiseControl1=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.cruiseControl1#index"))self.buttonCruiseControl2=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.cruiseControl2#index"))self.frontHydraulicMaxRot=Utils.getVectorNFromString(Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.frontHydraulic#maxRot"),"0 -50 0"),3)self.backHydraulicMaxRot=Utils.getVectorNFromString(Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.backHydraulic#maxRot"),"0 -50 0"),3)self.backTrailerLowMaxRot=Utils.getVectorNFromString(Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.backTrailerLow#maxRot"),"0 -50 0"),3)self.backTrailerMaxRot=Utils.getVectorNFromString(Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.backTrailer#maxRot"),"0 -50 0"),3)self.cruiseControlMaxRot1=Utils.getVectorNFromString(Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.cruiseControl1#maxRot"),"85 0 0"),3)self.cruiseControlMaxRot2=Utils.getVectorNFromString(Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.buttons.cruiseControl2#maxRot"),"-85 0 0"),3)self.fuelTankFull=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.fuelTank.full#index"))self.fuelTankWarning=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.fuelTank.warning#index"))self.fuelTankReserve=Utils.indexToObject(self.components,getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.fuelTank.reserve#index"))self.driveSymbols={}local c=0;local d={"FORWARD_ARROW","BACKWARD_ARROW","NEUTRAL_ARROW","FOUR_WHEEL","DIFF_LOCK_FRONT","DIFF_LOCK_BACK","TURN_LIGHT0","TURN_LIGHT1","TURN_LIGHT2","HAZARD_LIGHT","PTO_LIGHT_FRONT","PTO_LIGHT_BACK","HANDBRAKE_LIGHT","OIL_PRESSURE_LIGHT","AIR_PRESSURE_LIGHT","CRUISE_CONTROL","CONTROL_LIGHTS","TIPPING_ACTIVE","TIPPING_INACTIVE","TIPPING_SIDE_LEFT1","TIPPING_SIDE_RIGHT1","TIPPING_SIDE_BACK1","TIPPING_SIDE_GRAINDOOR1","TIPPING_SIDE_LEFT2","TIPPING_SIDE_RIGHT2","TIPPING_SIDE_BACK2","TIPPING_SIDE_GRAINDOOR2","TRAILER1","TRAILER2","TOOL_FRONT_LOWERED","TOOL_BACK_LOWERED","TOOL_FRONT_LIFTED","TOOL_BACK_LIFTED","TOOL_FRONT_ATTACHED","TOOL_BACK_ATTACHED"}local function e(f,g)for h=1,#f do if string.upper(f[h])==g then return true end end;return false end;local i=""local function j(f)for k,g in pairs(f)do if i~=""then g=", "..g end;i=i..g end;return string.upper(i)end;while true do local l="vehicle.animatedIndoorParts.driveSymbols.driveSymbol("..tostring(c)..")"if not hasXMLProperty(self.xmlFile,l)then break end;local m={}m.index=Utils.indexToObject(self.components,getXMLString(self.xmlFile,l.."#index"))if m.index~=nil then setVisibility(m.index,false)m.name=string.upper(Utils.getNoNil(getXMLString(self.xmlFile,l.."#name"),d[1]))if e(d,m.name)then if m.name=="CONTROL_LIGHTS"then m.displayTime=Utils.getNoNil(getXMLFloat(self.xmlFile,l.."#displayTime"),2200)m.currentTime=1 elseif m.name=="OIL_PRESSURE_LIGHT"then m.turnOffTimer=0;m.lightDelay=Utils.getNoNil(getXMLString(self.xmlFile,l.."#delay"),1)*1000;m.motorWasOn=false;m.pedalWasToMetal=false;m.stopToCount=false end;table.insert(self.driveSymbols,m)else print("Error from the AnimatedIndoorParts.lua: Found unsupportet drive symbol name '"..m.name.."' (drive symbol number "..c+1 ..")! Supportet names: "..j(d))i=""end end;c=c+1 end;self.numberOfAttachedTrailers=0;self.oldGear=1;self.oldGear2=self.oldGear;self.oldRange=1;self.oldDirection=1;self.oldNeutral=false;self.oldReverse=true;self.trailerFillLevelDisplay=VehicleHudUtils.loadHud(self,self.xmlFile,"trailerFillLevelDisplay")self.lastTrailerFillLevel=0;self.trailerFillWeightDisplay=VehicleHudUtils.loadHud(self,self.xmlFile,"trailerFillWeightDisplay")self.lastTrailerFillWeight=0;self.temperaturDayDisplay=VehicleHudUtils.loadHud(self,self.xmlFile,"temperaturDayDisplay")self.lastDayTemperatur=99;self.temperaturNightDisplay=VehicleHudUtils.loadHud(self,self.xmlFile,"temperaturNightDisplay")self.lastNightTemperatur=99;self.savedBaleWeight=0;self.allowedAddWeight=true;self.getBaleWeight=AnimatedIndoorParts.getBaleWeight;self.getFillWeight=AnimatedIndoorParts.getFillWeight;self.firstRunIsPending=true;self.steeringAnimation=Utils.getNoNil(getXMLString(self.xmlFile,"vehicle.animatedIndoorParts.steeringAnimation#name"),"")if self.steeringAnimation~=""then self.enterVehicle=Utils.prependedFunction(self.enterVehicle,AnimatedIndoorParts.enterVehicle)self.leaveVehicle=Utils.prependedFunction(self.leaveVehicle,AnimatedIndoorParts.leaveVehicle)end end;function AnimatedIndoorParts:enterVehicle(n,o,p)self:playAnimation(self.steeringAnimation,1,nil,true)end;function AnimatedIndoorParts:leaveVehicle(n,o,p)if not self:getIsHired()then self:playAnimation(self.steeringAnimation,-1,nil,true)end end;function AnimatedIndoorParts:getFillWeight(q)local r,s,t=0,0,0;for k,u in pairs(q.fillUnits)do if u.currentFillType~=nil and u.currentFillType~=FillUtil.FILLTYPE_UNKNOWN and FillUtil.fillTypeIndexToDesc[u.currentFillType].massPerLiter~=nil and not(q.isClassicsPackBaleLoader or u.currentFillType==FillUtil.FILLTYPE_SQUAREBALE or u.currentFillType==FillUtil.FILLTYPE_ROUNDBALE or u.currentFillType==FillUtil.FILLTYPE_PIG or u.currentFillType==FillUtil.FILLTYPE_SHEEP or u.currentFillType==FillUtil.FILLTYPE_COW)then r=FillUtil.fillTypeIndexToDesc[u.currentFillType].massPerLiter*1000 elseif u.currentFillType==FillUtil.FILLTYPE_SQUAREBALE or u.currentFillType==FillUtil.FILLTYPE_ROUNDBALE then local v=q;if v.baleGrabber~=nil then self.savedBaleWeight=self.savedBaleWeight+self:getBaleWeight(u.currentFillType==FillUtil.FILLTYPE_ROUNDBALE,v)else if v:getFillLevel()==1 and self.savedBaleWeight==0 or t~=v:getFillLevel()then if u.currentFillType==FillUtil.FILLTYPE_ROUNDBALE then self.savedBaleWeight=self.savedBaleWeight+math.random(260,320)else self.savedBaleWeight=self.savedBaleWeight+math.random(450,510)end;t=q:getFillLevel()end end elseif q.isClassicsPackBaleLoader then if q:getFillLevel()==1 and self.savedBaleWeight==0 or t~=q:getFillLevel()then self.savedBaleWeight=self.savedBaleWeight+math.random(15,20)t=q:getFillLevel()end elseif u.currentFillType==FillUtil.FILLTYPE_PIG then r=350 elseif u.currentFillType==FillUtil.FILLTYPE_SHEEP then r=160 elseif u.currentFillType==FillUtil.FILLTYPE_COW then r=1100 end end;s=q:getFillLevel()*r;if self.savedBaleWeight>0 and q:getFillLevel()>0 then s=self.savedBaleWeight else self.savedBaleWeight=0 end;return s end;function AnimatedIndoorParts:getBaleWeight(w,v)local x,y,z=0,0,0;if v.baleGrabber.currentBale~=nil then local A=networkGetObject(v.baleGrabber.currentBale)if A~=nil then local B=Utils.getNoNil(FillUtil.fillTypeIntToName[A.fillType],"straw")if self.allowedAddWeight then if w then local C=Utils.round(Utils.getNoNil(tonumber(A.baleWidth),1.12),2)local D=Utils.round(Utils.getNoNil(tonumber(A.baleDiameter),1.3),2)x=C*D;if B=="straw"then y=x*160 elseif B=="grass_windrow"then y=x*200 elseif B=="dryGrass_windrow"then y=x*140 elseif B=="silage"then y=x*600 end else local C=Utils.round(Utils.getNoNil(tonumber(A.baleWidth),1.2),2)local E=Utils.round(Utils.getNoNil(tonumber(A.baleHeight),0.9),2)local F=Utils.round(Utils.getNoNil(tonumber(A.baleLength),2.4),2)x=C*E*F;if B=="straw"then y=x*160 elseif B=="grass_windrow"then y=x*200 elseif B=="dryGrass_windrow"then y=x*140 elseif B=="silage"then y=x*600 end end;self.allowedAddWeight=false;z=y+math.random(20,80)end end else self.allowedAddWeight=true end;return z end;function AnimatedIndoorParts:getSaveAttributesAndNodes(G)if self.savedBaleWeight>0 then return'baleWeight="'..self.savedBaleWeight..'"',nil end;return nil,nil end;function AnimatedIndoorParts:update(H)if self:getIsActive()and self.isClient then local I,J,K,L=self.mrGbMGetIsOn~=nil and self:mrGbMGetIsOn(),true,false,false;local M=self.movingDirection<0;local N=M;local O,P,Q=false,false,false;local R,S,T=false,false,false;local U,V,s=0,0,0;local W,X=true,false;local Y,Z,_,a0,a1,a2,a3,a4=false,false,false,false,false,false,false,false;local a5,a6,a7,a8,a9,aa=false,false,false,false,false,false;local ab=self.cruiseControl.speed/self.cruiseControl.maxSpeed;if self.cruiseControl.state==Drivable.CRUISECONTROL_STATE_FULL then ab=1 end;if self.buttonFrontHydraulic~=nil then setRotation(self.buttonFrontHydraulic,0,0,0)end;if self.buttonBackHydraulic~=nil then setRotation(self.buttonBackHydraulic,0,0,0)end;if self.buttonBackTrailerLow~=nil then setRotation(self.buttonBackTrailerLow,0,0,0)end;if self.buttonBackTrailer~=nil then setRotation(self.buttonBackTrailer,0,0,0)end;if#self.attachedImplements>0 or self.numberOfAttachedTrailers>0 then self.numberOfAttachedTrailers=0;for ac=1,#self.attachedImplements do local ad=self.attachedImplements[ac].object;X=ad.tipState~=nil and ad.tipState~=Trailer.TIPSTATE_CLOSED;if ad.hoseSets~=nil and ad.attacherJoint.dynamicHoseIndice~=nil and ad.dynamicHoseIsManual then W=ad.attacherJoint.dynamicHoseIsAttached end;if ad.getFillLevel~=nil and ad.getCapacity~=nil then if self.trailerFillWeightDisplay~=nil then s=s+self:getFillWeight(ad)end;if self.trailerFillLevelDisplay~=nil then U=U+ad:getFillLevel()V=V+ad:getCapacity()end end;if ad.preferedTipReferencePointIndex~=nil then local ae=ad.tipAnimations[ad.preferedTipReferencePointIndex]if ae~=nil then Y=ae.name==g_i18n:getText("info_tipSideLeft")Z=ae.name==g_i18n:getText("info_tipSideRight")_=ae.name==g_i18n:getText("info_tipSideBack")a0=ae.name==g_i18n:getText("info_tipSideBackGrainDoor")end end;if ad.hasTurnLights and W then self.numberOfAttachedTrailers=self.numberOfAttachedTrailers+1 end;local af=ad.attacherVehicle:getImplementIndexByObject(ad)local ag=ad.attacherVehicle.attachedImplements[af]local ah=ag.jointDescIndex;local ai=ad.attacherVehicle.attacherJoints[ah]if ad.ptoInput~=nil then ai.isPTOActive=ad.turnOnVehicle~=nil and ad:getIsTurnedOn()or ad.animations~=nil and ad.animations["unfoldHand"]~=nil and ad:getIsAnimationPlaying("unfoldHand")or ad.animations~=nil and ad.animations["unloading"]~=nil and ad:getIsAnimationPlaying("unloading")or SpecializationUtil.hasSpecialization(ManureBarrel,ad.specializations)and ad.isFilling or ad.overloading~=nil and ad.overloading.didOverload or X or SpecializationUtil.hasSpecialization(BaleLoader,ad.specializations)and ad.isInWorkPosition or ad.baler~=nil and ad.baler.isBaleUnloading end;local aj,ak,al=getRotation(ai.jointTransform)if math.floor(math.deg(aj))==90 and math.floor(math.deg(ak))==81 and math.floor(math.deg(al))==90 then if ai.jointType==AttacherJoints.JOINTTYPE_TRAILERLOW then if SpecializationUtil.hasSpecialization(Cultivator,ad.specializations)or SpecializationUtil.hasSpecialization(Plough,ad.specializations)then if ad.isLowered~=nil then if self.buttonBackHydraulic~=nil then if ad:isLowered()then setRotation(self.buttonBackHydraulic,math.rad(self.backHydraulicMaxRot[1]),math.rad(self.backHydraulicMaxRot[2]),math.rad(self.backHydraulicMaxRot[3]))else setRotation(self.buttonBackHydraulic,-math.rad(self.backHydraulicMaxRot[1]),-math.rad(self.backHydraulicMaxRot[2]),-math.rad(self.backHydraulicMaxRot[3]))end end end else if self.buttonBackTrailerLow~=nil then if X or ai.isPTOActive then setRotation(self.buttonBackTrailerLow,math.rad(self.backTrailerLowMaxRot[1]),math.rad(self.backTrailerLowMaxRot[2]),math.rad(self.backTrailerLowMaxRot[3]))else setRotation(self.buttonBackTrailerLow,-math.rad(self.backTrailerLowMaxRot[1]),-math.rad(self.backTrailerLowMaxRot[2]),-math.rad(self.backTrailerLowMaxRot[3]))end end end elseif ai.jointType==AttacherJoints.JOINTTYPE_TRAILER then if self.buttonBackTrailer~=nil then if X or ai.isPTOActive then setRotation(self.buttonBackTrailer,math.rad(self.backTrailerMaxRot[1]),math.rad(self.backTrailerMaxRot[2]),math.rad(self.backTrailerMaxRot[3]))else setRotation(self.buttonBackTrailer,-math.rad(self.backTrailerMaxRot[1]),-math.rad(self.backTrailerMaxRot[2]),-math.rad(self.backTrailerMaxRot[3]))end end end;a6=Utils.getNoNil(ai.isPTOActive,false)end;if ai.bottomArm~=nil then if ai.bottomArm.zScale==1 then if ai.allowsLowering then a7=ad:isLowered()end;if self.buttonFrontHydraulic~=nil then if a7 then setRotation(self.buttonFrontHydraulic,math.rad(self.frontHydraulicMaxRot[1]),math.rad(self.frontHydraulicMaxRot[2]),math.rad(self.frontHydraulicMaxRot[3]))else setRotation(self.buttonFrontHydraulic,-math.rad(self.frontHydraulicMaxRot[1]),-math.rad(self.frontHydraulicMaxRot[2]),-math.rad(self.frontHydraulicMaxRot[3]))end end;a5=Utils.getNoNil(ai.isPTOActive,false)a9=true elseif ai.bottomArm.zScale==-1 then if ai.allowsLowering then a8=ad:isLowered()end;if self.buttonBackHydraulic~=nil then if a8 then setRotation(self.buttonBackHydraulic,math.rad(self.backHydraulicMaxRot[1]),math.rad(self.backHydraulicMaxRot[2]),math.rad(self.backHydraulicMaxRot[3]))else setRotation(self.buttonBackHydraulic,-math.rad(self.backHydraulicMaxRot[1]),-math.rad(self.backHydraulicMaxRot[2]),-math.rad(self.backHydraulicMaxRot[3]))end end;a6=Utils.getNoNil(ai.isPTOActive,false)aa=true end end;if#ad.attachedImplements>0 then for am=1,#ad.attachedImplements do local an=self.attachedImplements[ac].object;local ad=an.attachedImplements[am].object;if ad.hoseSets~=nil and ad.attacherJoint.dynamicHoseIndice~=nil and ad.dynamicHoseIsManual then W=ad.attacherJoint.dynamicHoseIsAttached end;if ad.getFillLevel~=nil and ad.getCapacity~=nil then if self.trailerFillWeightDisplay~=nil then s=s+self:getFillWeight(ad)end;if self.trailerFillLevelDisplay~=nil then U=U+ad:getFillLevel()V=V+ad:getCapacity()end end;if ad.tipState~=nil and ad.tipState~=Trailer.TIPSTATE_CLOSED then X=true end;if ad.hasTurnLights and W then self.numberOfAttachedTrailers=self.numberOfAttachedTrailers+1 end;if ad.preferedTipReferencePointIndex~=nil and self.numberOfAttachedTrailers==2 then local ae=ad.tipAnimations[ad.preferedTipReferencePointIndex]if ae~=nil then a1=ae.name==g_i18n:getText("info_tipSideLeft")a2=ae.name==g_i18n:getText("info_tipSideRight")a3=ae.name==g_i18n:getText("info_tipSideBack")a4=ae.name==g_i18n:getText("info_tipSideBackGrainDoor")end end end end end end;if self.fuelTankFull~=nil then setVisibility(self.fuelTankFull,self.fuelFillLevel>self.fuelCapacity*0.25 and self:getIsMotorStarted())end;if self.fuelTankWarning~=nil then setVisibility(self.fuelTankWarning,self.fuelFillLevel<self.fuelCapacity*0.25 and self.fuelFillLevel>self.fuelCapacity*0.16 and self:getIsMotorStarted())end;if self.fuelTankReserve~=nil then setVisibility(self.fuelTankReserve,self.fuelFillLevel<self.fuelCapacity*0.16 and self:getIsMotorStarted())end;if self.trailerFillLevelDisplay~=nil and self.lastTrailerFillLevel~=U then VehicleHudUtils.setHudValue(self,self.trailerFillLevelDisplay,math.ceil(U),V)self.lastTrailerFillLevel=U end;if self.temperaturDayDisplay~=nil and self.lastDayTemperatur~=g_currentMission.environment.weatherTemperaturesDay[1]then VehicleHudUtils.setHudValue(self,self.temperaturDayDisplay,g_currentMission.environment.weatherTemperaturesDay[1],99)self.lastDayTemperatur=g_currentMission.environment.weatherTemperaturesDay[1]end;if self.temperaturNightDisplay~=nil and self.lastNightTemperatur~=g_currentMission.environment.weatherTemperaturesNight[1]then VehicleHudUtils.setHudValue(self,self.temperaturNightDisplay,g_currentMission.environment.weatherTemperaturesNight[1],99)self.lastNightTemperatur=g_currentMission.environment.weatherTemperaturesNight[1]end;if self.trailerFillWeightDisplay~=nil and self.lastTrailerFillWeight~=s then VehicleHudUtils.setHudValue(self,self.trailerFillWeightDisplay,math.ceil(s),999999)self.lastTrailerFillWeight=s end;if self.mrGbMGetReverseActive~=nil and I then N=self:mrGbMGetReverseActive()end;if self.clutch~=nil then local aj,k,k=getRotation(self.clutch)K=aj~=0 end;if self.buttonCruiseControl1~=nil then setRotation(self.buttonCruiseControl1,math.rad(self.cruiseControlMaxRot1[1]*ab),math.rad(self.cruiseControlMaxRot1[2]*ab),math.rad(self.cruiseControlMaxRot1[3]*ab))end;if self.buttonCruiseControl2~=nil then setRotation(self.buttonCruiseControl2,math.rad(self.cruiseControlMaxRot2[1]*ab),math.rad(self.cruiseControlMaxRot2[2]*ab),math.rad(self.cruiseControlMaxRot2[3]*ab))end;if self.driveControl~=nil then if self.dCcheckModule~=nil then if self:dCcheckModule("fourWDandDifferentials")~=nil then O=self.driveControl.fourWDandDifferentials.fourWheel;P=self.driveControl.fourWDandDifferentials.diffLockFront;Q=self.driveControl.fourWDandDifferentials.diffLockBack end;if self:dCcheckModule("shuttle")~=nil and self.driveControl.shuttle.isActive and not I then J=self.driveControl.shuttle.direction>0;M=self.driveControl.shuttle.reverseDirection;if self.firstRunIsPending then if self.driveControl.shuttle.isActive and self.animations["groupGearShiftFromRange2ToR"]~=nil then self:playAnimation("groupGearShiftFromRange2ToR",-1,nil,true)self.firstRunIsPending=false end end;if self.oldDirection~=self.driveControl.shuttle.direction then if self.animations["setClutch"]~=nil then self:playAnimation("setClutch",1,nil,true)end;if self.oldReverse~=not J then if self.animations["groupGearShiftFromRange2ToR"]~=nil then if not J then self:playAnimation("groupGearShiftFromRange2ToR",1,nil,true)else self:playAnimation("groupGearShiftFromRange2ToR",-1,nil,true)end end;self.oldReverse=not J end;self.oldDirection=self.driveControl.shuttle.direction else local ao=self.animations["groupGearShiftFromRange2ToR"]~=nil and self:getIsAnimationPlaying("groupGearShiftFromRange2ToR")or self.animations["setClutch"]and self:getIsAnimationPlaying("setClutch")if self.animations["setClutch"]~=nil and not ao then self:playAnimation("setClutch",-1,nil,true)end end end end end;if J then if self.axisForward<=0 then if self.throttle~=nil then local k,ak,al=getRotation(self.throttle)if not K and not self.isReverseDriving then setRotation(self.throttle,math.rad(-self.throttleMaxRotX*self.axisForward),ak,al)else setRotation(self.throttle,0,ak,al)end;if self.throttleLinkage~=nil then local k,ak,al=getRotation(self.throttleLinkage)if not K and not self.isReverseDriving then setRotation(self.throttleLinkage,math.rad(self.throttleMaxRotX*self.axisForward),ak,al)else setRotation(self.throttleLinkage,0,ak,al)end end end end;if self.axisForward>=0 then if self.brake~=nil then local k,ak,al=getRotation(self.brake)setRotation(self.brake,math.rad(self.brakeMaxRotX*self.axisForward),ak,al)end end else if self.axisForward>=0 then if self.throttle~=nil then local k,ak,al=getRotation(self.throttle)if not K and not self.isReverseDriving then setRotation(self.throttle,math.rad(self.throttleMaxRotX*self.axisForward),ak,al)else setRotation(self.throttle,0,ak,al)end;if self.throttleLinkage~=nil then local k,ak,al=getRotation(self.throttleLinkage)if not K and not self.isReverseDriving then setRotation(self.throttleLinkage,math.rad(-self.throttleMaxRotX*self.axisForward),ak,al)else setRotation(self.throttleLinkage,0,ak,al)end end end end;if self.axisForward<=0 then if self.brake~=nil then local k,ak,al=getRotation(self.brake)setRotation(self.brake,math.rad(-self.brakeMaxRotX*self.axisForward),ak,al)end end end;if I then local ap=self:mrGbMGetCurrentGear()local aq=self:mrGbMGetNeutralActive()local ar=self:mrGbMGetCurrentRange()local as=self:mrGbMGetReverseActive()local at=self:mrGbMGetHandThrottle()local au=false;local av=1;R=self:mrGbMGetDiffLockMiddle()S=self:mrGbMGetDiffLockFront()T=self:mrGbMGetDiffLockBack()L=self.mrGbMS.Handbrake;if ar==3 then ar=self.oldRange;au=true end;if not self.isFirstRunDone then self:mrGbMSetNeutralActive(true)if self.animations["setHandbrake"]~=nil then self:playAnimation("setHandbrake",1,nil,true)end;self.isFirstRunDone=true end;if self.handThrottle~=nil then setRotation(self.handThrottle,math.rad(self.handThrottleMaxRot[1]*at),math.rad(self.handThrottleMaxRot[2]*at),math.rad(self.handThrottleMaxRot[3]*at))end;if(InputBinding.isPressed(InputBinding.gearboxMogliCLUTCH_3)or self.oldGear~=ap or self.oldRange~=ar or self.oldNeutral~=aq and not self.isHired or self.oldReverse~=as)and not aq then if self.animations["setClutch"]~=nil then self:playAnimation("setClutch",1,nil,true)end else local ao=self.animations["gearShiftFrom"..ap.."To"..self.oldGear2]~=nil and self:getIsAnimationPlaying("gearShiftFrom"..ap.."To"..self.oldGear2)or self.animations["gearShiftFrom"..self.oldGear2 .."To"..ap]~=nil and self:getIsAnimationPlaying("gearShiftFrom"..self.oldGear2 .."To"..ap)or self.animations["gearShiftFrom"..ap.."ToN"]~=nil and self:getIsAnimationPlaying("gearShiftFrom"..ap.."ToN")or self.animations["groupGearShiftFromRange"..ar.."ToN"]~=nil and self:getIsAnimationPlaying("groupGearShiftFromRange"..ar.."ToN")or self.animations["groupGearShiftFromRange"..ar.."ToR"]~=nil and self:getIsAnimationPlaying("groupGearShiftFromRange"..ar.."ToR")or self.animations["groupGearShiftFromRange1ToRange2"]~=nil and self:getIsAnimationPlaying("groupGearShiftFromRange1ToRange2")or self.animations["groupGearShiftFromRangeRToN"]~=nil and self:getIsAnimationPlaying("groupGearShiftFromRangeRToN")or self.animations["setClutch"]~=nil and self:getIsAnimationPlaying("setClutch")if self.animations["setClutch"]~=nil and not ao then self:playAnimation("setClutch",-1,nil,true)end end;if self.oldGear~=ap then if not aq then if self.oldGear<ap then if self.animations["gearShiftFrom"..self.oldGear.."To"..ap]~=nil then self:playAnimation("gearShiftFrom"..self.oldGear.."To"..ap,1,nil,true)end else if self.animations["gearShiftFrom"..ap.."To"..self.oldGear]~=nil then self:playAnimation("gearShiftFrom"..ap.."To"..self.oldGear,-1,nil,true)end end end;self.oldGear2=self.oldGear;self.oldGear=ap end;if self.oldRange~=ar or au then if not aq then if self.oldRange<ar then if self.animations["groupGearShiftFromRange"..self.oldRange.."ToRange"..ar]~=nil then self:playAnimation("groupGearShiftFromRange"..self.oldRange.."ToRange"..ar,1,nil,true)end else if self.animations["groupGearShiftFromRange"..ar.."ToRange"..self.oldRange]~=nil then self:playAnimation("groupGearShiftFromRange"..ar.."ToRange"..self.oldRange,-1,nil,true)end end end;self.oldRange=ar end;if self.oldNeutral~=aq and not self.isHired then if as then av=1 else av=-1 end;if self.animations["groupGearShiftFromRange"..ar.."ToR"]~=nil and not aq then self:playAnimation("groupGearShiftFromRange"..ar.."ToR",av,nil,true)end;if aq then av=1 else av=-1 end;if self.animations["gearShiftFrom"..ap.."ToN"]~=nil then self:playAnimation("gearShiftFrom"..ap.."ToN",av,nil,true)end;if self.animations["groupGearShiftFromRange"..ar.."ToN"]~=nil then self:playAnimation("groupGearShiftFromRange"..ar.."ToN",av,nil,true)end;if as then if self.animations["groupGearShiftFromRangeRToN"]~=nil then self:playAnimation("groupGearShiftFromRangeRToN",av,nil,true)end end;if self.animations["setHandbrake"]~=nil then self:playAnimation("setHandbrake",av,nil,true)end;self.oldNeutral=aq end;if self.oldReverse~=as then if as then av=1 else av=-1 end;if self.animations["groupGearShiftFromRange"..ar.."ToR"]~=nil and not aq then self:playAnimation("groupGearShiftFromRange"..ar.."ToR",av,nil,true)end;self.oldReverse=as end end;if self.driveSymbols~=nil then for k,m in pairs(self.driveSymbols)do if self.isMotorStarted then if m.name=="FORWARD_ARROW"then setVisibility(m.index,not(N or M)and self.lastSpeedReal>1.0E-5)elseif m.name=="BACKWARD_ARROW"then setVisibility(m.index,(N or M)and self.lastSpeedReal>1.0E-5)elseif m.name=="NEUTRAL_ARROW"then setVisibility(m.index,self.lastSpeedReal<1.0E-5)elseif m.name=="FOUR_WHEEL"then setVisibility(m.index,R or O)elseif m.name=="DIFF_LOCK_FRONT"then setVisibility(m.index,S or P)elseif m.name=="DIFF_LOCK_BACK"then setVisibility(m.index,T or Q)elseif m.name=="PTO_LIGHT_FRONT"then setVisibility(m.index,a5)elseif m.name=="PTO_LIGHT_BACK"then setVisibility(m.index,a6)elseif m.name=="HANDBRAKE_LIGHT"then setVisibility(m.index,L)elseif m.name=="CRUISE_CONTROL"then setVisibility(m.index,self.cruiseControl~=nil and self.cruiseControl.state==Drivable.CRUISECONTROL_STATE_ACTIVE)elseif m.name=="CONTROL_LIGHTS"then if m.currentTime<m.displayTime then setVisibility(m.index,true)end;if m.currentTime<m.displayTime+m.displayTime and m.currentTime>m.displayTime then setVisibility(m.index,false)end;m.currentTime=m.currentTime+H elseif m.name=="TIPPING_ACTIVE"then setVisibility(m.index,X)elseif m.name=="TIPPING_INACTIVE"then setVisibility(m.index,not X)elseif m.name=="TIPPING_SIDE_LEFT1"then setVisibility(m.index,Y)elseif m.name=="TIPPING_SIDE_RIGHT1"then setVisibility(m.index,Z)elseif m.name=="TIPPING_SIDE_BACK1"then setVisibility(m.index,_)elseif m.name=="TIPPING_SIDE_GRAINDOOR1"then setVisibility(m.index,a0)elseif m.name=="TIPPING_SIDE_LEFT2"then setVisibility(m.index,a1)elseif m.name=="TIPPING_SIDE_RIGHT2"then setVisibility(m.index,a2)elseif m.name=="TIPPING_SIDE_BACK2"then setVisibility(m.index,a3)elseif m.name=="TIPPING_SIDE_GRAINDOOR2"then setVisibility(m.index,a4)elseif m.name=="TRAILER1"then setVisibility(m.index,self.numberOfAttachedTrailers>=1)elseif m.name=="TRAILER2"then setVisibility(m.index,self.numberOfAttachedTrailers>=2)elseif m.name=="TOOL_FRONT_LOWERED"then setVisibility(m.index,a7)elseif m.name=="TOOL_BACK_LOWERED"then setVisibility(m.index,a8)elseif m.name=="TOOL_FRONT_LIFTED"then setVisibility(m.index,not a7)elseif m.name=="TOOL_BACK_LIFTED"then setVisibility(m.index,not a8)elseif m.name=="OIL_PRESSURE_LIGHT"then if not m.stopToCount then if self.throttle~=nil then local aj,k,k=getRotation(self.throttle)if aj~=0 and not self.pedalWasToMetal then m.lightTurnOffTimer=m.lightDelay+g_currentMission.time;m.pedalWasToMetal=true end else m.turnOffTimer=m.delay+g_currentMission.time end end;if m.motorWasOn~=self.isMotorStarted then setVisibility(m.index,true)m.motorWasOn=not self.isMotorStarted end;if m.turnOffTimer~=0 then if m.turnOffTimer<g_currentMission.time then m.turnOffTimer=0;setVisibility(m.index,false)m.stopToCount=true else setVisibility(m.index,true)end else if m.motorWasOn==self.isMotorStarted or m.stopToCount then setVisibility(m.index,false)end end elseif m.name=="AIR_PRESSURE_LIGHT"and self.brakeCompressor~=nil then local aw=Utils.round(self.brakeCompressor.fillLevel/self.brakeCompressor.capacity,2)*100;setVisibility(m.index,aw<41)elseif m.name=="TOOL_FRONT_ATTACHED"then setVisibility(m.index,a9)elseif m.name=="TOOL_BACK_ATTACHED"then setVisibility(m.index,aa)end else setVisibility(m.index,false)if m.name=="CONTROL_LIGHTS"then m.currentTime=1 end;if m.name=="OIL_PRESSURE_LIGHT"then m.stopToCount=false;m.pedalWasToMetal=false end end;if m.name=="TURN_LIGHT0"then setVisibility(m.index,self.numberOfAttachedTrailers>=0 and self.turnLightState~=Lights.TURNLIGHT_OFF)elseif m.name=="TURN_LIGHT1"then setVisibility(m.index,self.numberOfAttachedTrailers>=1 and self.turnLightState~=Lights.TURNLIGHT_OFF)elseif m.name=="TURN_LIGHT2"then setVisibility(m.index,self.numberOfAttachedTrailers>=2 and self.turnLightState~=Lights.TURNLIGHT_OFF)elseif m.name=="HAZARD_LIGHT"then setVisibility(m.index,self.turnLightState==Lights.TURNLIGHT_HAZARD)end end end;if self.vehicleCharacter~=nil then self.vehicleCharacter:setDirty()end end end;function AnimatedIndoorParts:delete()end;function AnimatedIndoorParts:mouseEvent(ax,ay,az,aA,aB)end;function AnimatedIndoorParts:keyEvent(aC,aD,aE,az)end;function AnimatedIndoorParts:draw()end